@@ -26,15 +26,15 @@
  *      |
  *      +-- {SYS_MGMNT_MODULE,[1-2]}    (Management Module)
  *      |
- *      +-- {INTERCONNECT,[1-4]}        (Switch Module)
+ *      +-- {INTERCONNECT,[1-4]}        (I/O Module)
  *      |
  *      +-- {SBC_BLADE,[1-14]}          (Blade)
  *      |   |
- *      |   +-- {EXPANSION_CARD,[1-14]} (Blade expansion card (BSE card))
- *      |                               (Expansion card number match's)
- *      |                               (it's parent blade's number)
+ *      |   +-- {EXPANSION_CARD,[1-14]} (Blade expansion modules (BEMs) (e.g. BSE))
+ *      |       |
+ *      |       +-- {DISK_DRIVE,[1-3]}  (Blade expansion module DASD)
  *      |
- *      +-- {PERIPHERAL_BAY,1}          (Control Panel/Media Tray)
+ *      +-- {PERIPHERAL_BAY,1}          (Media Tray)
  *      |
  *      +-- {POWER_SUPPLY,[1-4]}        (Power Module)
  *      |
@@ -59,8 +59,8 @@
  * plugin at run-time during resource discovery.
  *************************************************************************/
 
-#ifndef __BC_RESOURCES_H
-#define __BC_RESOURCES_H
+#ifndef __SNMP_BC_RESOURCES_H
+#define __SNMP_BC_RESOURCES_H
 
 /* Start HPI location numbers from 1 */
 #define SNMP_BC_HPI_LOCATION_BASE 1
@@ -106,9 +106,20 @@ typedef enum {
         BC_RPT_ENTRY_MEDIA_TRAY,
         BC_RPT_ENTRY_BLOWER_MODULE,
         BC_RPT_ENTRY_POWER_MODULE,
-	BC_RPT_ENTRY_PHYSICAL_SLOT
+	BC_RPT_ENTRY_PHYSICAL_SLOT,
+	BC_RPT_ENTRY_BEM_DASD
 } BCRptEntryT;
 
+
+/* Matching mmblade.mib definitions */		
+/*	storageExpansion(1),        */
+/* 	pciExpansion(2)             */
+typedef enum {
+        DEFAULT_BLADE_EXPANSION_CARD_TYPE = 0,
+	BLADE_STORAGE_EXPANSION,
+	BLADE_PCI_EXPANSION
+} BCExpansionTypeT;
+
 typedef enum {
 	RSA_RPT_ENTRY_CHASSIS = 0,
 	RSA_RPT_ENTRY_CPU,
@@ -143,7 +154,7 @@ typedef enum {
 /* OID definitions for discovering resources.*/
 #if 0
 #define SNMP_BC_BLADE_VECTOR            ".1.3.6.1.4.1.2.3.51.2.22.4.25.0"
-#define SNMP_BC_FAN_VECTOR              ".1.3.6.1.4.1.2.3.51.2.22.4.33.0"
+#define SNMP_BC_BLOWER_VECTOR           ".1.3.6.1.4.1.2.3.51.2.22.4.33.0"
 #define SNMP_BC_MEDIA_TRAY_EXISTS       ".1.3.6.1.4.1.2.3.51.2.22.4.32.0"
 #define SNMP_BC_MGMNT_VECTOR            ".1.3.6.1.4.1.2.3.51.2.22.4.30.0"
 #define SNMP_BC_POWER_VECTOR            ".1.3.6.1.4.1.2.3.51.2.22.4.31.0"
@@ -151,7 +162,9 @@ typedef enum {
 #endif
 
 #define SNMP_BC_BLADE_EXPANSION_VECTOR  ".1.3.6.1.4.1.2.3.51.2.22.1.5.1.1.14.x"
-#define SNMP_BC_MGMNT_ACTIVE            ".1.3.6.1.4.1.2.3.51.2.22.4.34.0" /* mmblade.mib - chassisActiveMM */
+#define SNMP_BC_BLADE_EXP_BLADE_BAY	".1.3.6.1.4.1.2.3.51.2.2.21.4.3.1.19.x" /* bladeExpBoardVpdBladeBayNumber */
+#define SNMP_BC_BLADE_EXP_TYPE		".1.3.6.1.4.1.2.3.51.2.2.21.4.3.1.20.x" /* bladeExpBoardVpdCardType */
+#define SNMP_BC_MGMNT_ACTIVE            ".1.3.6.1.4.1.2.3.51.2.22.4.34.0" 	/* chassisActiveMM */
 #define SNMP_BC_DST                     ".1.3.6.1.4.1.2.3.51.2.4.4.2.0"
 
 #define SNMP_BC_DST_RSA                 ".1.3.6.1.4.1.2.3.51.1.4.4.2.0"
@@ -169,26 +182,16 @@ typedef enum {
 #define SNMP_BC_SEL_CLEAR_OID           ".1.3.6.1.4.1.2.3.51.2.3.4.3.0"
 #define SNMP_BC_SEL_CLEAR_OID_RSA       ".1.3.6.1.4.1.2.3.51.1.3.4.3.0"
 
-/* Slot Numbers */
-#define BLADECENTER_INTERCONNECT_SLOT      SAHPI_ENT_CHASSIS_SPECIFIC + 0x10
-#define BLADECENTER_POWER_SUPPLY_SLOT      SAHPI_ENT_CHASSIS_SPECIFIC + 0x11
-#define BLADECENTER_PERIPHERAL_BAY_SLOT    SAHPI_ENT_CHASSIS_SPECIFIC + 0x12
-#define BLADECENTER_SYS_MGMNT_MODULE_SLOT  SAHPI_ENT_CHASSIS_SPECIFIC + 0x13
-#define BLADECENTER_FAN_SLOT               SAHPI_ENT_CHASSIS_SPECIFIC + 0x14
-
-/* Sensor Numbers defined for Blade Center Physical Slot resource */
-#define BLADECENTER_SENSOR_NUM_SLOT_STATE  	(SaHpiSensorNumT) 0x1010
-#define BLADECENTER_SENSOR_NUM_MAX_POWER  	(SaHpiSensorNumT) 0x1012
-#define BLADECENTER_SENSOR_NUM_ASSIGNED_POWER  	(SaHpiSensorNumT) 0x1011
-#define BLADECENTER_SENSOR_NUM_MIN_POWER  	(SaHpiSensorNumT) 0x1013
+/* mmHeathState OID */
+#define SNMP_BC_MM_HEALTH_OID           ".1.3.6.1.4.1.2.3.51.2.22.5.1.1.5.1"
 
 /* Slot ResourceTag */
-#define BC_PHYSICAL_SLOT  	 "Blade Center - Processor Blade Slot"
-#define BC_INTERCONNECT_SLOT 	 "Blade Center - Interconnect Slot"
-#define BC_POWER_SUPPLY_SLOT 	 "Blade Center - Power Supply Slot"
-#define BC_PERIPHERAL_BAY_SLOT   "Blade Center - Peripheral Bay Slot"
-#define BC_SYS_MGMNT_MODULE_SLOT "Blade Center - Management Module Slot"
-#define BC_FAN_SLOT 		 "Blade Center - Blower/Fan Slot"
+#define SNMP_BC_PHYSICAL_SLOT  	      "Blade Slot"
+#define SNMP_BC_INTERCONNECT_SLOT     "I/O Module Slot"
+#define SNMP_BC_POWER_SUPPLY_SLOT     "Power Module Slot"
+#define SNMP_BC_PERIPHERAL_BAY_SLOT   "Media Tray Slot"
+#define SNMP_BC_SYS_MGMNT_MODULE_SLOT "Management Module Slot"
+#define SNMP_BC_BLOWER_SLOT 	      "Blower Slot"
 
 /* Slot Power OIDs  */
 #define SNMP_BC_PD1POWERCURRENT ".1.3.6.1.4.1.2.3.51.2.2.10.2.1.1.7" /* pd1ModuleAllocatedPowerCurrent */
@@ -230,6 +233,8 @@ struct ResourceMibInfo {
 #define SNMP_BC_MAX_EVENTS_PER_RESOURCE 10
 #define SNMP_BC_MAX_RESOURCE_EVENT_ARRAY_SIZE (SNMP_BC_MAX_EVENTS_PER_RESOURCE + 1)
 
+
+
 /* For BladeCenter resources, some managed hot swap state events
   (e.g. INSERTION_PENDING and EXTRACTION_PENDING) are automatically generated.
   The "auto" fields below determine the auto-generated events. It's assummed 
@@ -300,8 +305,8 @@ struct SensorMibInfo {
 };
 
 /*  Size definitions include an ending NULL entry */
-#define SNMP_BC_MAX_EVENTS_PER_SENSOR 24
-#define SNMP_BC_MAX_READING_MAPS_PER_SENSOR 3
+#define SNMP_BC_MAX_EVENTS_PER_SENSOR 128
+#define SNMP_BC_MAX_READING_MAPS_PER_SENSOR 6
 #define SNMP_BC_MAX_SENSOR_EVENT_ARRAY_SIZE  (SNMP_BC_MAX_EVENTS_PER_SENSOR + 1)
 #define SNMP_BC_MAX_SENSOR_READING_MAP_ARRAY_SIZE (SNMP_BC_MAX_READING_MAPS_PER_SENSOR + 1)
 
@@ -348,6 +353,7 @@ struct snmp_bc_sensor {
 
 struct snmp_bc_ipmi_sensor {
 	const char *ipmi_tag;
+	const char *ipmi_tag_alias1;
 	struct snmp_bc_sensor ipmi;
 };
 
@@ -357,11 +363,14 @@ extern struct snmp_bc_sensor      snmp_bc_blade_sensors[];
 extern struct snmp_bc_ipmi_sensor snmp_bc_blade_ipmi_sensors[];
 extern struct snmp_bc_sensor      snmp_bc_bem_sensors[];
 extern struct snmp_bc_ipmi_sensor snmp_bc_bem_ipmi_sensors[];
+extern struct snmp_bc_sensor      snmp_bc_bse_dasd_sensors[];
+extern struct snmp_bc_sensor      snmp_bc_bse3_dasd_sensors[];
 extern struct snmp_bc_sensor      snmp_bc_mgmnt_sensors[];
+extern struct snmp_bc_sensor      snmp_bc_mgmnt_health_sensors[];
 extern struct snmp_bc_sensor      snmp_bc_virtual_mgmnt_sensors[];
 extern struct snmp_bc_sensor      snmp_bc_mediatray_sensors[];
-extern struct snmp_bc_sensor      snmp_bc_fan_sensors[];
-extern struct snmp_bc_sensor      snmp_bc_fan_sensors_bch[];
+extern struct snmp_bc_sensor      snmp_bc_blower_sensors[];
+extern struct snmp_bc_sensor      snmp_bc_blower_sensors_bch[];
 extern struct snmp_bc_sensor      snmp_bc_power_sensors[];
 extern struct snmp_bc_sensor      snmp_bc_power_sensors_bch[];
 extern struct snmp_bc_sensor      snmp_bc_switch_sensors[];
@@ -412,10 +421,11 @@ extern struct snmp_bc_control snmp_bc_bem_controls[];
 extern struct snmp_bc_control snmp_bc_mgmnt_controls[];
 extern struct snmp_bc_control snmp_bc_virtual_mgmnt_controls[];
 extern struct snmp_bc_control snmp_bc_mediatray_controls[];
-extern struct snmp_bc_control snmp_bc_fan_controls[];
+extern struct snmp_bc_control snmp_bc_blower_controls[];
 extern struct snmp_bc_control snmp_bc_power_controls[];
 extern struct snmp_bc_control snmp_bc_switch_controls[];
 extern struct snmp_bc_control snmp_bc_slot_controls[];
+extern struct snmp_bc_control snmp_bc_bem_dasd_controls[];
 
 extern struct snmp_bc_control snmp_bc_chassis_controls_rsa[];
 extern struct snmp_bc_control snmp_bc_cpu_controls_rsa[];
@@ -456,7 +466,7 @@ struct snmp_bc_inventory {
 };
 
 extern struct snmp_bc_inventory snmp_bc_chassis_inventories[];
-extern struct snmp_bc_inventory snmp_bc_fan_inventories[];
+extern struct snmp_bc_inventory snmp_bc_blower_inventories[];
 extern struct snmp_bc_inventory snmp_bc_mgmnt_inventories[];
 extern struct snmp_bc_inventory snmp_bc_virtual_mgmnt_inventories[];
 extern struct snmp_bc_inventory snmp_bc_switch_inventories[];
@@ -465,6 +475,7 @@ extern struct snmp_bc_inventory snmp_bc_bem_inventories[];
 extern struct snmp_bc_inventory snmp_bc_mediatray_inventories[];
 extern struct snmp_bc_inventory snmp_bc_power_inventories[];
 extern struct snmp_bc_inventory snmp_bc_slot_inventories[];
+extern struct snmp_bc_inventory snmp_bc_bem_dasd_inventories[];
 
 extern struct snmp_bc_inventory snmp_bc_chassis_inventories_rsa[];
 extern struct snmp_bc_inventory snmp_bc_cpu_inventories_rsa[];
