@@ -37,6 +37,7 @@ static int snmp_bc_get_sel_size(struct oh_handler_state *handle, SaHpiResourceId
 {
         int i;
 	SaErrorT err;
+	SaHpiEventLogInfoT elinfo;
 	
 	i = 1;
 	err = SA_OK;
@@ -52,51 +53,11 @@ static int snmp_bc_get_sel_size(struct oh_handler_state *handle, SaHpiResourceId
 		dbg("snmp_bc_discover, Error %s when building elcache.\n", oh_lookup_error(err));
 
 	/* Return the entry count */
-        i = g_list_length(handle->elcache->elentries);
+	oh_el_info(handle->elcache, &elinfo);
+        i = elinfo.Entries;
         return i;
 }
 
-/**
- * snmp_bc_get_sel_size_from_hardware:
- * @ss: Pointer to SNMP session data.
- * 
- * Unfortunately, hardware SNMP support does not provide access to the number 
- * of entries in the event log. This routine finds the number by sequentially 
- * reading the entire log index and counting the number of entries.
- *
- * Notice that this routine always reads one past the max event number's OID. 
- * It relies on a non-zero return code from SNMP to determine when there are 
- * no more entries.
- *
- * Return values:
- * Number of event log entries - normal case.
- **/
- /* ------------------------------------------------------------------------------------- */
- /* This routine is no longer needed. Keep it here (with #if 0) for documentation purpose */
-#if 0
-static int snmp_bc_get_sel_size_from_hardware(struct snmp_bc_hnd *custom_handle)
-{
-        struct snmp_value run_value;
-        char oid[SNMP_BC_MAX_OID_LENGTH];
-        int i;
-
-	i = 1;
-        do {
-		if (custom_handle->platform == SNMP_BC_PLATFORM_RSA) {
-			snprintf(oid, SNMP_BC_MAX_OID_LENGTH, "%s.%d", SNMP_BC_SEL_INDEX_OID_RSA, i);
-		}
-		else {
-			snprintf(oid, SNMP_BC_MAX_OID_LENGTH, "%s.%d", SNMP_BC_SEL_INDEX_OID, i);
-		}
-                i++;
-        } while(snmp_bc_snmp_get(custom_handle, oid, &run_value, SAHPI_TRUE) == 0);
-        
-        /* Think about it, and it makes sense */
-        i -= 2;
-        return i;
-}
-
-#endif
 /**
  * snmp_bc_get_sel_info:
  * @hnd: Pointer to handler's data.
@@ -119,7 +80,7 @@ SaErrorT snmp_bc_get_sel_info(void *hnd, SaHpiResourceIdT id, SaHpiEventLogInfoT
         struct tm curtime;
         sel_entry sel_entry;
     	struct snmp_bc_hnd *custom_handle;
-        SaHpiEventLogInfoT sel;
+        SaHpiEventLogInfoT sel, elinfo;
 	
         if (!hnd || !info) {
                 dbg("Invalid parameter.");
@@ -183,7 +144,8 @@ SaErrorT snmp_bc_get_sel_info(void *hnd, SaHpiResourceIdT id, SaHpiEventLogInfoT
 
 
         sel.Entries = snmp_bc_get_sel_size(handle, id);
-	sel.OverflowFlag = handle->elcache->overflow;
+	oh_el_info(handle->elcache, &elinfo);
+	sel.OverflowFlag = elinfo.OverflowFlag;
         *info = sel;
         snmp_bc_unlock_handler(custom_handle);
         return(SA_OK);
@@ -223,6 +185,8 @@ SaErrorT snmp_bc_get_sel_entry(void *hnd,
                 return(SA_ERR_HPI_INVALID_PARAMS);
         }
 	       
+	memset(entry, 0, sizeof(SaHpiEventLogEntryT));
+
 	err = SA_OK;
 	tmpentryptr = &tmpentry; 
 	handle = (struct oh_handler_state *)hnd;
@@ -236,7 +200,7 @@ SaErrorT snmp_bc_get_sel_entry(void *hnd,
                 if (err) {
                         dbg("Event Log cache sync failed %s\n", oh_lookup_error(err));
                         /* --------------------------------------------------------------- */
-                        /* If an error is encounterred during building of snmp_bc elcache, */
+                        /* If an error is encountered during building of snmp_bc elcache,  */
                         /* only log the error.  Do not do any recovery because log entries */
                         /* are still kept in bc mm.  We'll pick them up during synch.      */
                         /* --------------------------------------------------------------- */
@@ -476,6 +440,7 @@ SaErrorT snmp_bc_check_selcache(struct oh_handler_state *handle,
 				SaHpiEventLogEntryIdT entryId)
 {
 	SaErrorT err;
+	SaHpiEventLogInfoT elinfo;
 	
 	if (!handle) {
 		dbg("Invalid parameter.");
@@ -484,8 +449,9 @@ SaErrorT snmp_bc_check_selcache(struct oh_handler_state *handle,
 	
 	err = SA_OK;
 
-	if ((g_list_length(handle->elcache->elentries) == 0) && 
-	     !(is_simulator())) {
+	oh_el_info(handle->elcache, &elinfo);
+	if (elinfo.Entries == 0 && 
+	    !(is_simulator())) {
 		/* err = snmp_bc_build_selcache(handle, id); */
 		trace("elcache sync called before discovery?\n");
 	} else {
@@ -619,28 +585,21 @@ SaErrorT snmp_bc_selcache_sync(struct oh_handler_state *handle,
 		if (cacheupdate) {
 			GList *proc_log = NULL;
 			proc_log = g_list_first(sync_log);
-
 			while(proc_log != NULL) {
 				this_value = (struct snmp_value *)proc_log->data;
 				err = snmp_bc_parse_sel_entry(handle,this_value->string, &sel_entry);
 				if (err != SA_OK) return(err);
 		
-				if (strncmp(get_value.string, EVT_EN_LOG_FULL, sizeof(EVT_EN_LOG_FULL)) == 0 )
-		 				handle->elcache->overflow = SAHPI_TRUE;
+				if (g_ascii_strncasecmp(get_value.string, EVT_EN_LOG_FULL, sizeof(EVT_EN_LOG_FULL)) == 0 )
+						oh_el_overflowset(handle->elcache, SAHPI_TRUE);
 		 
 				isdst = sel_entry.time.tm_isdst;
 				snmp_bc_log2event(handle, this_value->string, &tmpevent, isdst, &logsrc2res);
 
-				if ((tmpevent.EventType == SAHPI_ET_HOTSWAP) && 
-							(custom_handle->isFirstDiscovery == SAHPI_FALSE))
-				{
-					err = snmp_bc_rediscover(handle, &tmpevent, &logsrc2res);
-				}
-
 				/*  append to end-of-elcache and end-of-eventq   */
 				err = snmp_bc_add_entry_to_elcache(handle, &tmpevent, SAHPI_FALSE);
 				proc_log = g_list_next(proc_log);
-			
+
 			}
 			
 		} else {
@@ -690,39 +649,12 @@ SaErrorT snmp_bc_build_selcache(struct oh_handler_state *handle, SaHpiResourceId
 	err = SA_OK;
 	custom_handle = (struct snmp_bc_hnd *)handle->data;
 
-#if 0
-	/* ------------------------------------------------------------------ */
-	/*  This code block is disabled because we no longer reading EventLog */
-	/*  backward for BladeCenter and forward for RSA.  Rather, we read    */
-	/*  EventLog forward and re-order them by timestamps accordingly.     */
-	/*  Just leave code it here for documentation purposes.               */
-	/* ------------------------------------------------------------------ */  
-	int current;
-	current = snmp_bc_get_sel_size_from_hardware(custom_handle);
-
-	if (current > 0) {
-		for (i=1; i<=current; i++) {
-			err = snmp_bc_sel_read_add(handle, id, i, SAHPI_TRUE);
-			if ( (err == SA_ERR_HPI_OUT_OF_SPACE) || (err == SA_ERR_HPI_INVALID_PARAMS)) {
-				/* Either of these 2 errors prevent us from doing anything meaningful */
-				return(err);
-			} else if (err != SA_OK) {
-				/* other errors (mainly HPI_INTERNAL_ERROR or HPI_BUSY) means */
-				/* only this record has problem. record error then go to next */
-				dbg("Error, %s, encountered with EventLog entry %d\n", 
-				    oh_lookup_error(err), i);
-			}
-		}
-	}
-#endif
-	/*  End-of-obsolete code                                              */
-	/* ------------------------------------------------------------------ */
-
 	/* ------------------------------------------------------------------- */
 	/* If user has configured for snmpV3, then use GETBULK for performance */
 	/* Else, stay with individual GETs                                     */
 	/* ------------------------------------------------------------------- */   
-	if (custom_handle->session.version == SNMP_VERSION_3)
+	if ((custom_handle->session.version == SNMP_VERSION_3) && 
+				(custom_handle->count_per_getbulk != 0))
 	{
 	
 		/* ------------------------------------------------- */
@@ -736,7 +668,8 @@ SaErrorT snmp_bc_build_selcache(struct oh_handler_state *handle, SaHpiResourceId
 		/* -- works OK with with multiple handlers           */
 		/*	gcc (GCC) 4.0.1 (4.0.1-5mdk  Mandriva 2006)  */
 		/* -- works OK with all gcc vers for single handler  */
-		trace(">>>>>> bulk build selcache %p.\n", handle);
+		trace(">>>>>> bulk build selcache %p. count_per_getbulk %d\n", 
+					handle,custom_handle->count_per_getbulk);
 		/* ------------------------------------------------- */
 				
 		err = snmp_bc_bulk_selcache(handle, id);
@@ -875,8 +808,8 @@ SaErrorT snmp_bc_sel_read_add (struct oh_handler_state *handle,
 	err = snmp_bc_parse_sel_entry(handle,get_value.string, &sel_entry);
 	if (err != SA_OK) return(err);
 		
-	if (strncmp(get_value.string, EVT_EN_LOG_FULL, sizeof(EVT_EN_LOG_FULL)) == 0 )
-		 handle->elcache->overflow = SAHPI_TRUE;
+	if (g_ascii_strncasecmp(get_value.string, EVT_EN_LOG_FULL, sizeof(EVT_EN_LOG_FULL)) == 0 )
+		oh_el_overflowset(handle->elcache, SAHPI_TRUE);
 		 
 	isdst = sel_entry.time.tm_isdst;
 	snmp_bc_log2event(handle, get_value.string, &tmpevent, isdst, &logsrc2res);
@@ -1023,11 +956,11 @@ SaErrorT snmp_bc_parse_sel_entry(struct oh_handler_state *handle, char *logstr,
 	findit = strstr(logstr, "Severity:");
 	if (findit != NULL) {
         	if(sscanf(findit,"Severity:%7s",level)) {
-                	if(strcmp(level,"INFO") == 0) {
+                	if(g_ascii_strncasecmp(level,"INFO", sizeof("INFO")) == 0) {
                         	ent.sev = SAHPI_INFORMATIONAL;
-                	} else if(strcmp(level,"WARN") == 0) {
+                	} else if(g_ascii_strncasecmp(level,"WARN", sizeof("WARN")) == 0) {
                         	ent.sev = SAHPI_MINOR;
-                	} else if(strcmp(level,"ERR") == 0) {
+                	} else if(g_ascii_strncasecmp(level,"ERR", sizeof("ERR")) == 0) {
                         	ent.sev = SAHPI_CRITICAL;
                 	} else {
                         	ent.sev = SAHPI_DEBUG;
