@@ -1,6 +1,6 @@
 /*      -*- linux-c -*-
  *
- * (C) Copyright IBM Corp. 2004
+ * (C) Copyright IBM Corp. 2004-2006
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -14,8 +14,13 @@
  *
  */
 
-#include <string.h>
 #include <sys/time.h>
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <fcntl.h>
+#include <unistd.h>
+#include <string.h>
+
 #include <oh_alarm.h>
 #include <oh_config.h>
 #include <oh_error.h>
@@ -73,7 +78,7 @@ static GSList *__get_alarm_node(struct oh_domain *d,
                     (num ? alarm->AlarmCond.SensorNum == *num : 1) &&
                     (state ? alarm->AlarmCond.EventState == *state : 1) &&
                     (unacknowledged ? !alarm->Acknowledged : 1)) {
-                        return alarms;
+			return alarms;
                 }
         }
 
@@ -107,12 +112,16 @@ static SaHpiUint32T __count_alarms(struct oh_domain *d,
 
 /**
  * oh_add_alarm
- * @d:
- * @alarm:
+ * @d: pointer to domain
+ * @alarm: alarm to be added
+ * @fromfile: if True will preserve alarm's id, timestamp, and
+ * acknowledge flag. Also, it will not save immediatedly to disk,
+ * if OPENHPI_DAT_SAVE is set.
  *
- * Return value:
+ * Return value: reference to newly added alarm or NULL if there was
+ * an error
  **/
-SaHpiAlarmT *oh_add_alarm(struct oh_domain *d, SaHpiAlarmT *alarm)
+SaHpiAlarmT *oh_add_alarm(struct oh_domain *d, SaHpiAlarmT *alarm, int fromfile)
 {
         struct timeval tv1;
         SaHpiAlarmT *a = NULL;
@@ -146,19 +155,23 @@ SaHpiAlarmT *oh_add_alarm(struct oh_domain *d, SaHpiAlarmT *alarm)
         }
 
         a = g_new0(SaHpiAlarmT, 1);
-        /* Is this 'if' below needed? g_new will stop program
-         * on a failed malloc anyway. Just in case...
-         */
-        if (!a) return NULL;
-
-        if (alarm) /* Copy contents of optional alarm reference */
+        if (alarm) { /* Copy contents of optional alarm reference */
                 memcpy(a, alarm, sizeof(SaHpiAlarmT));
-        a->AlarmId = ++(d->dat.next_id);
-        gettimeofday(&tv1, NULL);
-        a->Timestamp = (SaHpiTimeT) tv1.tv_sec * 1000000000 + tv1.tv_usec * 1000;
-        a->AlarmCond.DomainId = d->id;
-	a->Acknowledged = SAHPI_FALSE;
-        d->dat.list = g_slist_append(d->dat.list, a);
+	}
+
+	if (fromfile) {
+		if (a->AlarmId > d->dat.next_id) {
+			d->dat.next_id = a->AlarmId;
+		}
+	} else {
+		a->AlarmId = ++(d->dat.next_id);
+        	gettimeofday(&tv1, NULL);
+        	a->Timestamp =
+			(SaHpiTimeT) tv1.tv_sec * 1000000000 + tv1.tv_usec * 1000;
+		a->Acknowledged = SAHPI_FALSE;
+	}
+	a->AlarmCond.DomainId = d->id;
+	d->dat.list = g_slist_append(d->dat.list, a);
 
         /* Set alarm id and timestamp info in alarm reference */
         if (alarm) {
@@ -166,25 +179,38 @@ SaHpiAlarmT *oh_add_alarm(struct oh_domain *d, SaHpiAlarmT *alarm)
                 alarm->Timestamp = a->Timestamp;
         }
 
-        __update_dat(d);
+	if (!fromfile) {
+		__update_dat(d);
+		param.type = OPENHPI_DAT_SAVE;
+		oh_get_global_param(&param);
+		if (param.u.dat_save) {
+			char dat_filepath[SAHPI_MAX_TEXT_BUFFER_LENGTH*2];
+			param.type = OPENHPI_VARPATH;
+			oh_get_global_param(&param);
+			snprintf(dat_filepath, SAHPI_MAX_TEXT_BUFFER_LENGTH*2,
+					"%s/dat.%u", param.u.varpath, d->id);
+			oh_alarms_to_file(&d->dat, dat_filepath);
+		}
+	}
 
         return a;
 }
 
 /**
  * oh_get_alarm
- * @d:
- * @aid:
- * @severity:
- * @type:
- * @rid:
- * @mid:
- * @num:
- * @state:
- * @unacknowledged:
- * @get_next:
+ * @d: pointer to domain
+ * @aid: Optional. alarm id for alarm to get
+ * @severity: Optional. Severity of alarm to get
+ * @type: Optional. Type of alarm to get
+ * @rid: Optional. Resource Id of alarm to get
+ * @mid: Optional. Manufacturer Id of alarm to get
+ * @num: Optional. Sensor number of alarm to get
+ * @state: Optional. Event State of alarm to get
+ * @unacknowledged: If True, only gets unacknowledged.
+ * @get_next: Instead of getting the exact @aid, get the next alarm
+ * after that one
  *
- * Return value:
+ * Return value: pointer to SaHpiAlarmT that matched, or NULL of none found.
  **/
 SaHpiAlarmT *oh_get_alarm(struct oh_domain *d,
                           SaHpiAlarmIdT *aid,
@@ -210,17 +236,18 @@ SaHpiAlarmT *oh_get_alarm(struct oh_domain *d,
 
 /**
  * oh_remove_alarm
- * @d:
- * @severity:
- * @type:
- * @rid:
- * @mid:
- * @num:
- * @state:
- * @deassert_mask:
- * @multi:
+ * @d: pointer to domain
+ * @severity: Optional. Severity of alarm to remove
+ * @type: Optional. Type of alarm to remove
+ * @rid: Optional. Resource Id of alarm to remove
+ * @mid: Optional. Manufacturer Id of alarm to remove
+ * @num: Optional. Sensor Number of alarm to remove
+ * @state: Optional. Event state of alarm to remove
+ * @deassert_mask: Optional. Deassert Mask. Matches on a bit AND operation.
+ * @multi: If True, does operation for all matching alarms, otherwise,
+ * just the first matching one.
  *
- * Return value:
+ * Return value: SA_OK on success
  **/
 SaErrorT oh_remove_alarm(struct oh_domain *d,
                          SaHpiSeverityT *severity,
@@ -234,27 +261,22 @@ SaErrorT oh_remove_alarm(struct oh_domain *d,
 {
         GSList *alarm_node = NULL;
         SaHpiAlarmT *alarm = NULL;
-	SaHpiAlarmIdT saw_aid = SAHPI_FIRST_ENTRY; /* Set to zero */
+	SaHpiAlarmIdT aid = SAHPI_FIRST_ENTRY; /* Set to zero */
         struct oh_global_param param = { .type = OPENHPI_DAT_SIZE_LIMIT };
 
         if (!d) return SA_ERR_HPI_INVALID_PARAMS;
 
         do {
-                alarm_node = __get_alarm_node(d, NULL, severity, type, rid, mid,
-                                              num, state, 0, 0);
+                alarm_node = __get_alarm_node(d, &aid, severity, type, rid, mid,
+                                              num, state, 0, 1);
                 if (alarm_node) alarm = alarm_node->data;
 		else break;
 
-		if (alarm->AlarmId == saw_aid) break; /* Avoid infinite loop case */
-
-		saw_aid = alarm->AlarmId;
-
-                if (alarm &&
-                    (deassert_mask ? *deassert_mask & alarm->AlarmCond.EventState : 1)) {
+		aid = alarm->AlarmId;
+                if (deassert_mask ? *deassert_mask & alarm->AlarmCond.EventState : 1) {
                         d->dat.list = g_slist_delete_link(d->dat.list, alarm_node);
                         g_free(alarm);
                 }
-
                 alarm_node = NULL;
                 alarm = NULL;
         } while (multi);
@@ -271,9 +293,11 @@ SaErrorT oh_remove_alarm(struct oh_domain *d,
 
 /**
  * oh_close_alarmtable
- * @d:
+ * @d: pointer to domain
  *
- * Return value:
+ * Frees all memory held by alarm table.
+ *
+ * Return value: SA_OK on success
  **/
 SaErrorT oh_close_alarmtable(struct oh_domain *d)
 {
@@ -292,10 +316,13 @@ SaErrorT oh_close_alarmtable(struct oh_domain *d)
 
 /**
  * oh_count_alarms
- * @d:
- * @sev:
+ * @d: pointer to domain
+ * @sev: Severity of alarms to count
  *
- * Return value:
+ * Counts alarms in the domain table. You can count alarms of a specific
+ * severity, or for all severities (SAHPI_ALL_SEVERITIES).
+ *
+ * Return value: Number of alarms counted.
  **/
 SaHpiUint32T oh_count_alarms(struct oh_domain *d, SaHpiSeverityT sev)
 {
@@ -322,11 +349,11 @@ static void oh_detect_oem_event_alarm(struct oh_domain *d, SaHpiEventT *event)
         }
 
         /* Severity is "alarming". Add/Create OEM alarm */
-        a = oh_add_alarm(d, NULL);
+        a = oh_add_alarm(d, NULL, 0);
         if (!a) goto done;
         a->Severity = event->Severity;
         a->AlarmCond.Type = SAHPI_STATUS_COND_TYPE_OEM;
-        oh_entity_path_lookup(&event->Source, &a->AlarmCond.Entity);
+        oh_entity_path_lookup(event->Source, &a->AlarmCond.Entity);
         a->AlarmCond.ResourceId = event->Source;
         a->AlarmCond.Mid = event->EventDataUnion.OemEvent.MId;
         memcpy(&a->AlarmCond.Data,
@@ -352,11 +379,11 @@ static void oh_detect_resource_event_alarm(struct oh_domain *d, SaHpiEventT *eve
 
         /* Failed resource. Add/Create resource alarm if severity is "alarming" */
         if (event->Severity <= SAHPI_MINOR) {
-                a = oh_add_alarm(d, NULL);
+                a = oh_add_alarm(d, NULL, 0);
                 if (!a) goto done;
                 a->Severity = event->Severity;
                 a->AlarmCond.Type = SAHPI_STATUS_COND_TYPE_RESOURCE;
-                oh_entity_path_lookup(&event->Source, &a->AlarmCond.Entity);
+                oh_entity_path_lookup(event->Source, &a->AlarmCond.Entity);
                 a->AlarmCond.ResourceId = event->Source;
         }
 done:
@@ -381,11 +408,11 @@ static void oh_detect_sensor_event_alarm(struct oh_domain *d, SaHpiEventT *event
                    event->EventDataUnion.SensorEvent.Assertion) {
                 /* Add sensor alarm to dat, since event is severe
                    enough and is asserted. */
-                a = oh_add_alarm(d, NULL);
+                a = oh_add_alarm(d, NULL, 0);
                 if (!a) goto done;
                 a->Severity = event->Severity;
                 a->AlarmCond.Type = SAHPI_STATUS_COND_TYPE_SENSOR;
-                oh_entity_path_lookup(&event->Source, &a->AlarmCond.Entity);
+                oh_entity_path_lookup(event->Source, &a->AlarmCond.Entity);
                 a->AlarmCond.ResourceId = event->Source;
                 a->AlarmCond.SensorNum = event->EventDataUnion.SensorEvent.SensorNum;
                 a->AlarmCond.EventState = event->EventDataUnion.SensorEvent.EventState;
@@ -448,11 +475,11 @@ static void oh_detect_resource_alarm(struct oh_domain *d, SaHpiRptEntryT *res)
                                 NULL, NULL, NULL, 1);
         } else if (res->ResourceSeverity <= SAHPI_MINOR && res->ResourceFailed) {
                 /* Otherwise, if sev is "alarming" and resource failed, create alarm. */
-                a = oh_add_alarm(d, NULL);
+                a = oh_add_alarm(d, NULL, 0);
                 if (!a) goto done;
                 a->Severity = res->ResourceSeverity;
                 a->AlarmCond.Type = SAHPI_STATUS_COND_TYPE_RESOURCE;
-                oh_entity_path_lookup(&res->ResourceId, &a->AlarmCond.Entity);
+                oh_entity_path_lookup(res->ResourceId, &a->AlarmCond.Entity);
                 a->AlarmCond.ResourceId = res->ResourceId;
                 a->AlarmCond.Mid = res->ResourceInfo.ManufacturerId;
                 memcpy(&a->AlarmCond.Data, &res->ResourceTag, sizeof(SaHpiTextBufferT));
@@ -463,10 +490,11 @@ done:
 
 /**
  * oh_detect_event_alarm
- * @d:
- * @e:
+ * @e: pointer to event
  *
- * Return value:
+ * Study event and determine if alarms need to be removed.
+ *
+ * Return value: SA_OK on success
  **/
 SaErrorT oh_detect_event_alarm(struct oh_event *e)
 {
@@ -495,11 +523,14 @@ SaErrorT oh_detect_event_alarm(struct oh_event *e)
 
 /**
  * oh_detect_res_sev_alarm
- * @d:
- * @res:
- * @new_sev:
+ * @did: domain id
+ * @res: resource id
+ * @new_sev: severity being set in resource
  *
- * Return value:
+ * Detect if severity on resource change makes any alarms invalid.
+ * If so, remove such alarms.
+ *
+ * Return value: SA_OK on success
  **/
 SaErrorT oh_detect_res_sev_alarm(SaHpiDomainIdT did,
                                  SaHpiResourceIdT rid,
@@ -529,12 +560,15 @@ SaErrorT oh_detect_res_sev_alarm(SaHpiDomainIdT did,
 
 /**
  * oh_detect_sensor_alarm
- * @d:
- * @rid:
- * @num:
- * @enable:
+ * @did: domain id
+ * @rid: resource id
+ * @num: sensor number
+ * @enable: sensor enable flag
  *
- * Return value:
+ * This will detect if a sensor related alarm needs to be removed,
+ * and if so, will remove it accordingly.
+ *
+ * Return value: SA_OK on success
  **/
 SaErrorT oh_detect_sensor_enable_alarm(SaHpiDomainIdT did,
                                        SaHpiResourceIdT rid,
@@ -563,14 +597,16 @@ SaErrorT oh_detect_sensor_enable_alarm(SaHpiDomainIdT did,
 
 /**
  * oh_detect_sensor_mask_alarm
- * @d
- * @rid
- * @num
- * @action
- * @deassert_mask
+ * @did: domain id
+ * @rid: resource id
+ * @num: sensor number
+ * @action: event mask action
+ * @deassert_mask: deassert mask
  *
+ * This will detect if a sensor related alarm needs to be removed,
+ * and if so, will remove it accordingly.
  *
- * Return value:
+ * Return value: SA_OK on success
  **/
 SaErrorT oh_detect_sensor_mask_alarm(SaHpiDomainIdT did,
                                      SaHpiResourceIdT rid,
@@ -603,3 +639,88 @@ SaErrorT oh_detect_sensor_mask_alarm(SaHpiDomainIdT did,
         oh_release_domain(d);
         return error;
 }
+
+/**
+ * oh_alarms_to_file
+ *
+ * @at: pointer to alarm table. alarms in this table will be saved to a file
+ * @filename: file to which alarms will be saved.
+ *
+ * Return value: SA_OK on success.
+ **/
+SaErrorT oh_alarms_to_file(struct oh_dat *at, char *filename)
+{
+	GSList *alarms = NULL;
+	int file;
+
+	if (!at || !filename) {
+		dbg("Invalid Parameters");
+		return SA_ERR_HPI_INVALID_PARAMS;
+	}
+
+	file = open(filename, O_WRONLY | O_CREAT | O_TRUNC, 0660 );
+	if (file < 0) {
+		dbg("File '%s' could not be opened", filename);
+		return SA_ERR_HPI_ERROR;
+	}
+
+	for (alarms = at->list; alarms; alarms = alarms->next) {
+		int bytes_written = 0;
+		bytes_written = write(file, (void *)alarms->data, sizeof(SaHpiAlarmT));
+		if (bytes_written != sizeof(SaHpiAlarmT)) {
+			dbg("Couldn't write to file '%s'.", filename);
+                        close(file);
+                        return SA_ERR_HPI_ERROR;
+		}
+	}
+
+	if (close(file) != 0) {
+        	dbg("Couldn't close file '%s'.", filename);
+		return SA_ERR_HPI_ERROR;
+	}
+
+	return SA_OK;
+}
+
+/**
+ * oh_alarms_from_file
+ *
+ * @d: pointer to domain. alarm table in this domain will receive
+ * the alarms stored in @filename.
+ * @filename: filename where alarms will be read from
+ *
+ * Return value: SA_OK on success
+ **/
+SaErrorT oh_alarms_from_file(struct oh_domain *d, char *filename)
+{
+	int file;
+	SaHpiAlarmT alarm;
+
+	if (!d || !filename) {
+		dbg("Invalid Parameters");
+		return SA_ERR_HPI_ERROR;
+	}
+
+	file = open(filename, O_RDONLY);
+        if (file < 0) {
+                dbg("File '%s' could not be opened", filename);
+                return SA_ERR_HPI_ERROR;
+        }
+
+	while (read(file, &alarm, sizeof(SaHpiAlarmT)) == sizeof(SaHpiAlarmT)) {
+		SaHpiAlarmT *a = oh_add_alarm(d, &alarm, 1);
+		if (!a) {
+			close(file);
+			dbg("Error adding alarm read from file.");
+			return SA_ERR_HPI_ERROR;
+		}
+	}
+
+	if (close(file) != 0) {
+        	dbg("Couldn't close file '%s'.", filename);
+        	return SA_ERR_HPI_ERROR;
+	}
+
+	return SA_OK;
+}
+
