@@ -38,7 +38,7 @@ static const char *known_globals[] = {
         "OPENHPI_DEL_SAVE",
         "OPENHPI_DAT_SIZE_LIMIT",
         "OPENHPI_DAT_USER_LIMIT",
-        "OPENHPI_DAEMON_MODE",
+        "OPENHPI_DAT_SAVE",
         //"OPENHPI_DEBUG",
         //"OPENHPI_DEBUG_TRACE",
         //"OPENHPI_DEBUG_LOCK",
@@ -56,7 +56,7 @@ static struct {
         SaHpiBoolT del_save;
         SaHpiUint32T dat_size_limit;
         SaHpiUint32T dat_user_limit;
-        SaHpiUint32T daemon_mode;
+        SaHpiBoolT dat_save;
         //unsigned char dbg;
         //unsigned char dbg_trace;
         //unsigned char dbg_lock;
@@ -73,7 +73,7 @@ static struct {
         .del_save = SAHPI_FALSE,
         .dat_size_limit = 0, /* Unlimited size */
         .dat_user_limit = 0, /* Unlimited size */
-        .daemon_mode = 0, /* Are we a daemon if yes this is '1' */
+        .dat_save = SAHPI_FALSE,
         //.dbg = 0,
         //.dbg_trace = 0,
         //.dbg_lock = 0,
@@ -260,6 +260,12 @@ static void process_global_param(const char *name, char *value)
                 global_params.dat_size_limit = atoi(value);
         } else if (!strcmp("OPENHPI_DAT_USER_LIMIT", name)) {
                 global_params.dat_user_limit = atoi(value);
+        } else if (!strcmp("OPENHPI_DAT_SAVE", name)) {
+                if (!strcmp("YES", value)) {
+                        global_params.dat_save = SAHPI_TRUE;
+                } else {
+                        global_params.dat_save = SAHPI_FALSE;
+                }
         //} else if (!strcmp("OPENHPI_DEBUG", name)) {
         //        if (!strcmp("YES", value)) {
         //                global_params.dbg = 1;
@@ -278,14 +284,6 @@ static void process_global_param(const char *name, char *value)
         //        } else {
         //                global_params.dbg_lock = 0;
         //        }
-        } else if (!strcmp("OPENHPI_DAEMON_MODE", name)) {
-                g_static_rec_mutex_lock(&global_params.lock);
-                if (!strcmp("YES", value)) {
-                        global_params.daemon_mode = 1;
-                } else {
-                        global_params.daemon_mode = 0;
-                }
-                g_static_rec_mutex_unlock(&global_params.lock);
         } else if (!strcmp("OPENHPI_PATH", name)) {
                 g_static_rec_mutex_lock(&global_params.lock);
                 memset(global_params.path, 0, OH_MAX_TEXT_BUFFER_LENGTH);
@@ -755,8 +753,8 @@ int oh_get_global_param(struct oh_global_param *param)
                 case OPENHPI_DAT_USER_LIMIT:
                         param->u.dat_user_limit = global_params.dat_user_limit;
                         break;
-                case OPENHPI_DAEMON_MODE:
-                        param->u.daemon_mode = global_params.daemon_mode;
+                case OPENHPI_DAT_SAVE:
+                        param->u.dat_save = global_params.dat_save;
                         break;
                 //case OPENHPI_DEBUG:
                 //        param->u.dbg = global_params.dbg;
@@ -835,8 +833,8 @@ int oh_set_global_param(struct oh_global_param *param)
                 case OPENHPI_DAT_USER_LIMIT:
                         global_params.dat_user_limit = param->u.dat_user_limit;
                         break;
-                case OPENHPI_DAEMON_MODE:
-                        global_params.daemon_mode = param->u.daemon_mode;
+                case OPENHPI_DAT_SAVE:
+                        global_params.dat_save = param->u.dat_save;
                         break;
                 //case OPENHPI_DEBUG:
                 //        global_params.dbg = param->u.dbg;
