@@ -30,7 +30,7 @@
 /**
  * main: EL test
  *
- * This test verifies failure of oh_el_overflowreset when
+ * This test verifies failure of oh_el_info.OverflowFlagreset when
  * el == NULL 
  * Return value: 0 on success, 1 on failure
  **/
@@ -46,7 +46,7 @@ int main(int argc, char **argv)
 
 	retc = oh_el_overflowreset(el);
         if (retc == SA_OK) {
-                dbg("ERROR: el overflowreset failed.");
+                dbg("ERROR: oh_el_overflowreset failed.");
                 return 1;
         }
 
